@@ -1,17 +1,17 @@
-##
-## Copyright (C) 2006 Gajim Team
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+
 """
 Handles the jingle signalling protocol
 """
@@ -37,13 +37,13 @@ from gajim.common import app
 from gajim.common.jingle_session import JingleSession, JingleStates
 from gajim.common.jingle_ft import JingleFileTransfer
 from gajim.common.jingle_transport import JingleTransportSocks5, JingleTransportIBB
-if app.HAVE_FARSTREAM:
+if app.is_installed('FARSTREAM'):
     from gajim.common.jingle_rtp import JingleAudio, JingleVideo
 
 logger = logging.getLogger('gajim.c.jingle')
 
 
-class ConnectionJingle(object):
+class ConnectionJingle:
     """
     This object depends on that it is a part of Connection class.
     """
@@ -76,7 +76,7 @@ class ConnectionJingle(object):
         is a new session.
 
         TODO: Also check if the stanza isn't an error stanza, if so route it
-        adequatelly.
+        adequately.
         """
         # get data
         try:
@@ -181,15 +181,15 @@ class ConnectionJingle(object):
         if contact.supports(nbxmpp.NS_HASHES_2):
             if contact.supports(nbxmpp.NS_HASHES_BLAKE2B_512):
                 return 'blake2b-512'
-            elif contact.supports(nbxmpp.NS_HASHES_BLAKE2B_256):
+            if contact.supports(nbxmpp.NS_HASHES_BLAKE2B_256):
                 return 'blake2b-256'
-            elif contact.supports(nbxmpp.NS_HASHES_SHA3_512):
+            if contact.supports(nbxmpp.NS_HASHES_SHA3_512):
                 return 'sha3-512'
-            elif contact.supports(nbxmpp.NS_HASHES_SHA3_256):
+            if contact.supports(nbxmpp.NS_HASHES_SHA3_256):
                 return 'sha3-256'
-            elif contact.supports(nbxmpp.NS_HASHES_SHA512):
+            if contact.supports(nbxmpp.NS_HASHES_SHA512):
                 return 'sha-512'
-            elif contact.supports(nbxmpp.NS_HASHES_SHA256):
+            if contact.supports(nbxmpp.NS_HASHES_SHA256):
                 return 'sha-256'
         return None
 
@@ -202,14 +202,11 @@ class ConnectionJingle(object):
         if media:
             if media not in ('audio', 'video', 'file'):
                 return tuple()
-            else:
-                return (session for session in sessions if \
-                    session.get_content(media))
-        else:
-            return sessions
+            return (session for session in sessions if session.get_content(media))
+        return sessions
 
     def set_file_info(self, file_):
-        # Saves information about the files we have transfered in case they need
+        # Saves information about the files we have transferred in case they need
         # to be requested again.
         self.files.append(file_)
 
@@ -228,9 +225,8 @@ class ConnectionJingle(object):
         if sid:
             if sid in self._sessions:
                 return self._sessions[sid]
-            else:
-                return None
-        elif media:
+            return None
+        if media:
             if media not in ('audio', 'video', 'file'):
                 return None
             for session in self._sessions.values():
