@@ -1,38 +1,35 @@
-# -*- coding:utf-8 -*-
-## src/common/logging_helpers.py
-##
-## Copyright (C) 2009 Bruno Tarquini <btarquini AT gmail.com>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2009 Bruno Tarquini <btarquini AT gmail.com>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 import logging
 import os
 import sys
 
+from gajim.common.i18n import _
+
 def parseLogLevel(arg):
     """
     Eiter numeric value or level name from logging module
     """
     if arg.isdigit():
         return int(arg)
-    elif arg.isupper() and hasattr(logging, arg):
+    if arg.isupper() and hasattr(logging, arg):
         return getattr(logging, arg)
-    else:
-        print(_('%s is not a valid loglevel') % repr(arg))
-        return 0
+    print(_('%s is not a valid loglevel') % repr(arg))
+    return 0
 
 def parseLogTarget(arg):
     """
@@ -43,12 +40,11 @@ def parseLogTarget(arg):
     arg = arg.lower()
     if not arg:
         return 'gajim'
-    elif arg.startswith('.'):
+    if arg.startswith('.'):
         return arg[1:]
-    elif arg.startswith('gajim'):
+    if arg.startswith('gajim'):
         return arg
-    else:
-        return 'gajim.' + arg
+    return 'gajim.' + arg
 
 def parseAndSetLogLevels(arg):
     """
@@ -77,6 +73,7 @@ def parseAndSetLogLevels(arg):
 
 
 class colors:
+    # pylint: disable=C0326
     NONE         = chr(27) + "[0m"
     BLACk        = chr(27) + "[30m"
     RED          = chr(27) + "[31m"
@@ -103,11 +100,11 @@ class FancyFormatter(logging.Formatter):
     An eye-candy formatter with colors
     """
     colors_mapping = {
-            'DEBUG':                colors.BLUE,
-            'INFO':                colors.GREEN,
-            'WARNING':      colors.BROWN,
-            'ERROR':                colors.RED,
-            'CRITICAL':     colors.BRIGHT_RED,
+        'DEBUG': colors.BLUE,
+        'INFO': colors.GREEN,
+        'WARNING': colors.BROWN,
+        'ERROR': colors.RED,
+        'CRITICAL': colors.BRIGHT_RED,
     }
 
     def __init__(self, fmt, datefmt=None, use_color=False):
@@ -144,11 +141,11 @@ def init():
 
     consoleloghandler = logging.StreamHandler()
     consoleloghandler.setFormatter(
-            FancyFormatter(
-                    '%(asctime)s %(levelname)s %(name)s %(message)s',
-                    '%x %H:%M:%S',
-                    use_color
-            )
+        FancyFormatter(
+            '%(asctime)s %(levelname)s %(name)s %(message)s',
+            '%x %H:%M:%S',
+            use_color
+        )
     )
 
     # fake the root logger so we have 'gajim' root name instead of 'root'
