@@ -1,45 +1,44 @@
-# -*- coding:utf-8 -*-
-## src/common/socks5.py
-##
-## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
-##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
-## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
+#                         Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
+# Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 import socket
 import struct
 import hashlib
 import os
 import time
+import platform
+import logging
 from errno import EWOULDBLOCK
 from errno import ENOBUFS
 from errno import EINTR
 from errno import EISCONN
 from errno import EINPROGRESS
 from errno import EAFNOSUPPORT
+
 from nbxmpp.idlequeue import IdleObject
+import OpenSSL
+
 from gajim.common.file_props import FilesProp
 from gajim.common import app
 from gajim.common import jingle_xtls
-if jingle_xtls.PYOPENSSL_PRESENT:
-    import OpenSSL
-import logging
+
 log = logging.getLogger('gajim.c.socks5')
 MAX_BUFF_LEN = 65536
 # after foo seconds without activity label transfer as 'stalled'
@@ -80,7 +79,7 @@ class SocksQueue:
     def start_listener(self, port, sha_str, sha_handler, file_props,
     fingerprint=None, typ='sender'):
         """
-        Start waiting for incomming connections on (host, port) and do a socks5
+        Start waiting for incoming connections on (host, port) and do a socks5
         authentication using sid for generated SHA
         """
         log.debug('Start listening for socks5 connection')
@@ -99,15 +98,16 @@ class SocksQueue:
         return self.listener
 
     def send_success_reply(self, file_props, streamhost):
-        if file_props.streamhost_used == True:
+        if file_props.streamhost_used is True:
             for proxy in file_props.proxyhosts:
                 if proxy['host'] == streamhost['host']:
                     self.on_success[file_props.transport_sid](proxy)
                     return 1
             return 0
         for host in file_props.streamhosts:
-            if streamhost['state'] == 1:
-                return 0
+            if host['state'] == 1:
+                # on_success callback already called for another host
+                return 0 # return 0 to disconnect this one
         streamhost['state'] = 1
         self.on_success[file_props.transport_sid](streamhost)
         return 1
@@ -134,22 +134,22 @@ class SocksQueue:
                 fp = fingerprint
             if receiving:
                 if 'candidate_id' in streamhost:
-                    log.debug('Trying to connect as receiver to cid ' + \
-                        streamhost['candidate_id'])
+                    log.debug('Trying to connect as receiver to cid %s',
+                              streamhost['candidate_id'])
                 else:
-                    log.debug('Trying to connect as receiver to jid ' + \
-                        streamhost['jid'])
+                    log.debug('Trying to connect as receiver to jid %s',
+                              streamhost['jid'])
                 file_props.type_ = 'r'
                 socks5obj = Socks5ReceiverClient(self.idlequeue, streamhost,
                     transport_sid, file_props, fingerprint=fp)
                 self.add_sockobj(account, socks5obj)
             else:
                 if 'candidate_id' in streamhost:
-                    log.debug('Trying to connect as sender to cid ' + \
-                        streamhost['candidate_id'])
+                    log.debug('Trying to connect as sender to cid %s',
+                              streamhost['candidate_id'])
                 else:
-                    log.debug('Trying to connect as sender to jid ' + \
-                        streamhost['jid'])
+                    log.debug('Trying to connect as sender to jid %s',
+                              streamhost['jid'])
                 if file_props.sha_str:
                     idx = file_props.sha_str
                 else:
@@ -161,8 +161,8 @@ class SocksQueue:
                     file_props.proxy_sender = streamhost['target']
                     file_props.proxy_receiver = streamhost['initiator']
                 socks5obj = Socks5SenderClient(self.idlequeue, idx,
-                    self, _sock=None,host=str(streamhost['host']),
-                    port=int(streamhost['port']),fingerprint=fp,
+                    self, _sock=None, host=str(streamhost['host']),
+                    port=int(streamhost['port']), fingerprint=fp,
                     connected=False, file_props=file_props,
                     initiator=streamhost['initiator'],
                     target=streamhost['target'])
@@ -177,9 +177,9 @@ class SocksQueue:
         streamhosts. Stop other attempts for connections
         """
         if 'candidate_id' in streamhost:
-            log.debug('Connected to cid ' + streamhost['candidate_id'])
+            log.debug('Connected to cid %s', streamhost['candidate_id'])
         else:
-            log.debug('Connected to jid ' + streamhost['jid'])
+            log.debug('Connected to jid %s', streamhost['jid'])
         for host in file_props.streamhosts:
             if host != streamhost and 'idx' in host:
                 if host['state'] == 1:
@@ -190,7 +190,7 @@ class SocksQueue:
                         self.remove_receiver(streamhost['idx'])
                     return
                 # set state -2, meaning that this streamhost is stopped,
-                # but it may be connectected later
+                # but it may be connected later
                 if host['state'] >= 0:
                     if file_props.type_ == 's':
                         self.remove_sender(host['idx'], False)
@@ -215,7 +215,7 @@ class SocksQueue:
             if 'idx' in host:
                 if host['state'] >= 0:
                     return
-                elif host['state'] == -2:
+                if host['state'] == -2:
                     unused_hosts = True
         if unused_hosts:
             for host in file_props.streamhosts:
@@ -242,9 +242,10 @@ class SocksQueue:
         Called when we loose connection during transfer
         """
         if 'candidate_id' in streamhost:
-            log.debug('Connection refused to cid ' + streamhost['candidate_id'])
+            log.debug('Connection refused to cid %s',
+                      streamhost['candidate_id'])
         else:
-            log.debug('Connection refused to jid ' + streamhost['jid'])
+            log.debug('Connection refused to jid %s', streamhost['jid'])
         if file_props is None:
             return
         streamhost['state'] = -1
@@ -295,7 +296,7 @@ class SocksQueue:
     def activate_proxy(self, idx):
         if not self.isHashInSockObjs(self.senders, idx):
             return
-        for key in self.senders.keys():
+        for key in self.senders:
             if idx in key:
                 sender = self.senders[key]
                 if sender.file_props.type_ != 's':
@@ -330,12 +331,12 @@ class SocksQueue:
                 result = sender.send_file()
                 self.process_result(result, sender)
 
-    def isHashInSockObjs(self, sockobjs, hash):
+    def isHashInSockObjs(self, sockobjs, hash_):
         '''
         It tells wether there is a particular hash in sockobjs or not
         '''
         for key in sockobjs:
-            if hash in key:
+            if hash_ in key:
                 return True
         return False
 
@@ -343,7 +344,7 @@ class SocksQueue:
         sock_hash = sock.__hash__()
         if listener.file_props.type_ == 's' and \
         not self.isHashInSockObjs(self.senders, sock_hash):
-            sockobj =  Socks5SenderServer(self.idlequeue, sock_hash, self,
+            sockobj = Socks5SenderServer(self.idlequeue, sock_hash, self,
                 sock[0], sock[1][0], sock[1][1], fingerprint=None,
                 file_props=listener.file_props)
             self._add(sockobj, self.senders, listener.file_props, sock_hash)
@@ -357,8 +358,8 @@ class SocksQueue:
             sh['port'] = sock[1][1]
             sh['initiator'] = None
             sh['target'] = None
-            sockobj =  Socks5ReceiverServer(idlequeue=self.idlequeue,
-                streamhost=sh,transport_sid=None,
+            sockobj = Socks5ReceiverServer(idlequeue=self.idlequeue,
+                streamhost=sh, transport_sid=None,
                 file_props=listener.file_props, fingerprint=None)
 
             self._add(sockobj, self.readers, listener.file_props, sock_hash)
@@ -392,7 +393,7 @@ class SocksQueue:
         else:
             if reader.streamhost is not None:
                 reader.streamhost['state'] = -1
-        del(self.readers[key])
+        del self.readers[key]
 
     def remove_sender_by_key(self, key, do_disconnect=True):
         sender = self.senders[key]
@@ -400,20 +401,20 @@ class SocksQueue:
             sender.disconnect()
         self.idlequeue.unplug_idle(sender.fd)
         self.idlequeue.remove_timeout(sender.fd)
-        del(self.senders[key])
+        del self.senders[key]
         if self.connected > 0:
             self.connected -= 1
 
     def remove_receiver(self, idx, do_disconnect=True, remove_all=False):
         """
-        Remove reciver from the list and decrease the number of active
+        Remove receiver from the list and decrease the number of active
         connections with 1
         """
         if idx != -1:
             for key in list(self.readers.keys()):
                 if idx in key:
-                    self.remove_receiver_by_key(key,
-                        do_disconnect=do_disconnect)
+                    self.remove_receiver_by_key(
+                        key, do_disconnect=do_disconnect)
                     if not remove_all:
                         break
 
@@ -428,7 +429,7 @@ class SocksQueue:
                     self.remove_sender_by_key(key, do_disconnect=do_disconnect)
                     if not remove_all:
                         break
-            if len(self.senders) == 0 and self.listener is not None:
+            if not self.senders and self.listener is not None:
                 self.listener.disconnect()
                 self.listener = None
                 self.connected -= 1
@@ -452,7 +453,7 @@ class SocksQueue:
             if sock.host != host_to_keep and sock.mode == 'server':
                 self.remove_sender_by_key(key)
 
-class Socks5(object):
+class Socks5:
     def __init__(self, idlequeue, host, port, initiator, target, sid):
         if host is not None:
             try:
@@ -529,9 +530,9 @@ class Socks5(object):
     def do_connect(self):
         try:
             self._sock.connect(self._server)
-            self._send=self._sock.send
-            self._recv=self._sock.recv
-        except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError) as e:
+            self._send = self._sock.send
+            self._recv = self._sock.recv
+        except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError):
             pass
         except Exception as ee:
             errnum = ee.errno
@@ -542,12 +543,12 @@ class Socks5(object):
                 self.connected = False
                 return None
             # win32 needs this
-            elif errnum not in  (10056, EISCONN) or self.state != 0:
+            if errnum not in  (10056, EISCONN) or self.state != 0:
                 return None
-            else: # socket is already connected
-                self._sock.setblocking(False)
-                self._send=self._sock.send
-                self._recv=self._sock.recv
+            # socket is already connected
+            self._sock.setblocking(False)
+            self._send = self._sock.send
+            self._recv = self._sock.recv
         self.buff = ''
         self.connected = True
         self.file_props.connected = True
@@ -563,7 +564,7 @@ class Socks5(object):
         self.idlequeue.remove_timeout(self.fd)
         if self.state > 5:
             # no activity for foo seconds
-            if self.file_props.stalled == False:
+            if self.file_props.stalled is False:
                 self.file_props.stalled = True
                 self.queue.process_result(-1, self)
                 if not self.file_props.received_len:
@@ -643,12 +644,12 @@ class Socks5(object):
             add = self._recv(64)
         except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
         OpenSSL.SSL.WantX509LookupError) as e:
-            log.info('SSL rehandshake request : ' + repr(e))
+            log.info('SSL rehandshake request: %s', repr(e))
             raise e
         except Exception:
             add = b''
         received += add
-        if len(add) == 0:
+        if not add:
             self.disconnect()
         return add
 
@@ -660,7 +661,7 @@ class Socks5(object):
             self._send(raw_data)
         except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
         OpenSSL.SSL.WantX509LookupError) as e:
-            log.info('SSL rehandshake request :' + repr(e))
+            log.info('SSL rehandshake request: %s', repr(e))
             raise e
         except Exception:
             self.disconnect()
@@ -678,13 +679,13 @@ class Socks5(object):
                 self.file_props.error = -7 # unable to read from file
                 return -1
             buff = self.file.read(MAX_BUFF_LEN)
-        if len(buff) > 0:
+        if buff:
             lenn = 0
             try:
                 lenn = self._send(buff)
             except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
             OpenSSL.SSL.WantX509LookupError) as e:
-                log.info('SSL rehandshake request :' + repr(e))
+                log.info('SSL rehandshake request: %s', repr(e))
                 raise e
             except Exception as e:
                 if e.errno not in (EINTR, ENOBUFS, EWOULDBLOCK):
@@ -758,7 +759,7 @@ class Socks5(object):
                 buff = self._recv(MAX_BUFF_LEN)
             except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
             OpenSSL.SSL.WantX509LookupError) as e:
-                log.info('SSL rehandshake request :' + repr(e))
+                log.info('SSL rehandshake request: %s', repr(e))
                 raise e
             except Exception:
                 buff = b''
@@ -767,7 +768,7 @@ class Socks5(object):
                 self.file_props.last_time
             self.file_props.last_time = current_time
             self.file_props.received_len += len(buff)
-            if len(buff) == 0:
+            if not buff:
                 # Transfer stopped  somehow:
                 # reset, paused or network error
                 self.rem_fd(fd)
@@ -798,7 +799,7 @@ class Socks5(object):
                 return self.file_props.received_len
         return None
 
-    def disconnect(self):
+    def disconnect(self, *args, **kwargs):
         """
         Close open descriptors and remover socket descr. from idleque
         """
@@ -856,7 +857,7 @@ class Socks5(object):
             self.port >> 8, self.port & 0xff)
         return buff
 
-    def _get_request_buff(self, msg, command = 0x01):
+    def _get_request_buff(self, msg, command=0x01):
         """
         Connect request by domain name, sid sha, instead of domain name (jep
         0096)
@@ -898,7 +899,7 @@ class Socks5(object):
             buff = self._recv().decode('utf-8')
         except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
         OpenSSL.SSL.WantX509LookupError) as e:
-            log.info("SSL rehandshake request : " + repr(e))
+            log.info("SSL rehandshake request: %s", repr(e))
             raise e
         try:
             version, method = struct.unpack('!BB', buff)
@@ -932,7 +933,7 @@ class Socks5Sender(IdleObject):
     Class for sending file to socket over socks5
     """
     def __init__(self, idlequeue, sock_hash, parent, _sock, host=None,
-    port=None, fingerprint = None, connected=True, file_props=None):
+                 port=None, fingerprint=None, connected=True, file_props=None):
         self.fingerprint = fingerprint
         self.queue_idx = sock_hash
         self.queue = parent
@@ -1011,8 +1012,8 @@ class Socks5Sender(IdleObject):
 
 
 class Socks5Receiver(IdleObject):
-    def __init__(self, idlequeue, streamhost, sid, file_props = None,
-    fingerprint=None):
+    def __init__(self, idlequeue, streamhost, sid, file_props=None,
+                 fingerprint=None):
         """
         fingerprint: fingerprint of certificates we shall use, set to None if
         TLS connection not desired
@@ -1142,8 +1143,9 @@ class Socks5Server(Socks5):
                     self.idlequeue.set_read_timeout(self.fd, STALLED_TIMEOUT)
                     result = self.start_transfer() # send
                     self.queue.process_result(result, self)
-            except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
-            OpenSSL.SSL.WantX509LookupError) as e:
+            except (OpenSSL.SSL.WantReadError,
+                    OpenSSL.SSL.WantWriteError,
+                    OpenSSL.SSL.WantX509LookupError):
                 log.info('caught SSL exception, ignored')
         else:
             self.disconnect()
@@ -1180,8 +1182,9 @@ class Socks5Server(Socks5):
                 return
             else:
                 self.disconnect()
-        except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
-        OpenSSL.SSL.WantX509LookupError) as e:
+        except (OpenSSL.SSL.WantReadError,
+                OpenSSL.SSL.WantWriteError,
+                OpenSSL.SSL.WantX509LookupError):
             log.info('caught SSL exception, ignored')
             return
         if self.state < 5:
@@ -1222,15 +1225,17 @@ class Socks5Client(Socks5):
             addrlen = 0
             if address_type == 0x03:
                 addrlen = buff[4]
-                address = struct.unpack('!%ds' % addrlen, buff[5:addrlen + 5])
+                # address = struct.unpack('!%ds' % addrlen, buff[5:addrlen + 5])
                 portlen = len(buff[addrlen + 5:])
-                if portlen == 1:
-                    port, = struct.unpack('!B', buff[addrlen + 5])
-                elif portlen == 2:
-                    port, = struct.unpack('!H', buff[addrlen + 5:])
-                else: # Gaim bug :)
-                    port, = struct.unpack('!H', buff[addrlen + 5:addrlen + 7])
+                # if portlen == 1:
+                #     port, = struct.unpack('!B', buff[addrlen + 5])
+                # elif portlen == 2:
+                #     port, = struct.unpack('!H', buff[addrlen + 5:])
+                # else: # Gaim bug :)
+                #     port, = struct.unpack('!H', buff[addrlen + 5:addrlen + 7])
+                if portlen not in (1, 2):
                     self.remaining_buff = buff[addrlen + 7:]
+
             self.state = 5 # for senders: init file_props and send '\n'
             if self.queue.on_success:
                 result = self.queue.send_success_reply(self.file_props,
@@ -1271,8 +1276,9 @@ class Socks5Client(Socks5):
 
     def send_file(self):
         if self.ssl_errnum > 0:
-            log.error('remote certificate does not match the announced one.' + \
-                '\nSSL Error: %d\nCancelling file transfer' % self.ssl_errnum)
+            log.error('remote certificate does not match the announced one.'
+                      '\nSSL Error: %d\nCancelling file transfer',
+                      self.ssl_errnum)
             self.file_props.error = -12
             return -1
         return super(Socks5Client, self).send_file()
@@ -1294,8 +1300,9 @@ class Socks5Client(Socks5):
                     self.idlequeue.set_read_timeout(self.fd, STALLED_TIMEOUT)
                     result = self.start_transfer() # receive
                     self.queue.process_result(result, self)
-            except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
-            OpenSSL.SSL.WantX509LookupError) as e:
+            except (OpenSSL.SSL.WantReadError,
+                    OpenSSL.SSL.WantWriteError,
+                    OpenSSL.SSL.WantX509LookupError):
                 log.info('caught SSL exception, ignored')
                 return
         else:
@@ -1307,7 +1314,7 @@ class Socks5Client(Socks5):
             if self.state == 0:
                 self.do_connect()
                 return
-            elif self.state == 1: # send initially: version and auth types
+            if self.state == 1: # send initially: version and auth types
                 self.send_raw(self._get_auth_buff())
             elif self.state == 3: # send 'connect' request
                 self.send_raw(self._get_request_buff(self._get_sha1_auth()))
@@ -1318,8 +1325,9 @@ class Socks5Client(Socks5):
                 result = self.start_transfer() # send
                 self.queue.process_result(result, self)
                 return
-        except (OpenSSL.SSL.WantReadError, OpenSSL.SSL.WantWriteError,
-        OpenSSL.SSL.WantX509LookupError) as e:
+        except (OpenSSL.SSL.WantReadError,
+                OpenSSL.SSL.WantWriteError,
+                OpenSSL.SSL.WantX509LookupError):
             log.info('caught SSL exception, ignored')
             return
         self.state += 1
@@ -1339,23 +1347,23 @@ class Socks5Client(Socks5):
 
 class Socks5SenderClient(Socks5Client, Socks5Sender):
 
-    def __init__(self, idlequeue, sock_hash, parent,_sock, host=None,
-    port=None, fingerprint = None, connected=True, file_props=None,
+    def __init__(self, idlequeue, sock_hash, parent, _sock, host=None,
+    port=None, fingerprint=None, connected=True, file_props=None,
     initiator=None, target=None):
         Socks5Client.__init__(self, idlequeue, host, port, initiator, target,
             file_props.transport_sid)
-        Socks5Sender.__init__(self,idlequeue, sock_hash, parent,_sock,
-            host, port, fingerprint , connected, file_props)
+        Socks5Sender.__init__(self, idlequeue, sock_hash, parent, _sock,
+            host, port, fingerprint, connected, file_props)
 
 
 class Socks5SenderServer(Socks5Server, Socks5Sender):
 
-    def __init__(self, idlequeue, sock_hash, parent,_sock, host=None,
-    port=None, fingerprint = None, connected=True, file_props=None):
+    def __init__(self, idlequeue, sock_hash, parent, _sock, host=None,
+    port=None, fingerprint=None, connected=True, file_props=None):
         Socks5Server.__init__(self, idlequeue, host, port, None, None,
             file_props.transport_sid)
-        Socks5Sender.__init__(self,idlequeue, sock_hash, parent, _sock,
-            host, port, fingerprint , connected, file_props)
+        Socks5Sender.__init__(self, idlequeue, sock_hash, parent, _sock,
+            host, port, fingerprint, connected, file_props)
 
 
 class Socks5ReceiverClient(Socks5Client, Socks5Receiver):
@@ -1423,22 +1431,20 @@ class Socks5Listener(IdleObject):
             # Under windows Vista, we need that to listen on ipv6 AND ipv4
             # Doesn't work under windows XP
             if os.name == 'nt':
-                ver = os.sys.getwindowsversion()
-                if (ver[3], ver[0]) == (2, 6): # Win Vista +
+                if int(platform.win32_ver()[0]) >= 6:  # Win Vista +
                     # 47 is socket.IPPROTO_IPV6
                     # 27 is socket.IPV6_V6ONLY under windows, but not defined ...
                     self._serv.setsockopt(41, 27, 0)
             # will fail when port as busy, or we don't have rights to bind
             try:
                 self._serv.bind(ai[4])
-                f = ai[4]
                 self.ai = ai
                 break
             except Exception:
                 self.ai = None
                 continue
         if not self.ai:
-            log.error('unable to bind to port ' + str(self.port))
+            log.error('unable to bind to port %s', str(self.port))
             return None
         self._serv.listen(socket.SOMAXCONN)
         self._serv.setblocking(False)
@@ -1477,8 +1483,7 @@ class Socks5Listener(IdleObject):
         """
         Accept a new incomming connection
         """
-        _sock  = self._serv.accept()
+        _sock = self._serv.accept()
         _sock[0].setblocking(False)
         self.connections.append(_sock[0])
         return _sock
-
