@@ -1,29 +1,25 @@
-# -*- coding:utf-8 -*-
-## src/groups.py
-##
-## Copyright (C) 2006-2017 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2006 Tomasz Melcer <liori AT exroot.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2006 Tomasz Melcer <liori AT exroot.org>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 '''Window to create new post for discussion groups service.'''
 
-from common import gajim
+from gajim.common import app
 from nbxmpp import Node
-import gtkgui_helpers
+from gajim import gtkgui_helpers
 
 class GroupsPostWindow:
     def __init__(self, account, servicejid, groupid):
@@ -31,8 +27,8 @@ class GroupsPostWindow:
         Open new 'create post' window to create message for groupid on servicejid
         service
         """
-        assert isinstance(servicejid, basestring)
-        assert isinstance(groupid, basestring)
+        assert isinstance(servicejid, str)
+        assert isinstance(groupid, str)
 
         self.account = account
         self.servicejid = servicejid
@@ -64,10 +60,12 @@ class GroupsPostWindow:
         item.addChild('title', {}, [self.subject_entry.get_text()])
 
         buf = self.contents_textview.get_buffer()
-        item.addChild('content', {}, [buf.get_text(buf.get_start_iter(), buf.get_end_iter())])
+        item.addChild('content', {}, [buf.get_text(buf.get_start_iter(), buf.get_end_iter(), True)])
 
         # publish it to node
-        gajim.connections[self.account].send_pb_publish(self.servicejid, self.groupid, item, '0')
+        con = app.connections[self.account]
+        con.get_module('PubSub').send_pb_publish(
+            self.servicejid, self.groupid, item, '0')
 
         # close the window
         self.window.destroy()
